# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

---

## [Unreleased]

### Added
- Repo Files:
    - README.md
    - LICENSE
    - CHANGELOG.md
    - pyproject.toml
    - setup.cfg
    - test-requirements.txt
    - .gitignore
- Minimum Viable Product:
    - Rate limiting per IP/User.
    - Periodic rate-limit reset.
    - Unit tests